summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/gdboutputwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/gdboutputwidget.h')
-rw-r--r--languages/cpp/debugger/gdboutputwidget.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/languages/cpp/debugger/gdboutputwidget.h b/languages/cpp/debugger/gdboutputwidget.h
index ddf79823..0b14b599 100644
--- a/languages/cpp/debugger/gdboutputwidget.h
+++ b/languages/cpp/debugger/gdboutputwidget.h
@@ -18,10 +18,10 @@
#ifndef _GDBOUTPUTWIDGET_H_
#define _GDBOUTPUTWIDGET_H_
-#include <qwidget.h>
-#include <qtextedit.h>
-#include <qtimer.h>
-#include <qstringlist.h>
+#include <tqwidget.h>
+#include <tqtextedit.h>
+#include <tqtimer.h>
+#include <tqstringlist.h>
class KHistoryCombo;
@@ -37,11 +37,11 @@ class GDBOutputWidget : public QWidget
Q_OBJECT
public:
- GDBOutputWidget( QWidget *parent=0, const char *name=0 );
+ GDBOutputWidget( TQWidget *parent=0, const char *name=0 );
~GDBOutputWidget();
- void savePartialProjectSession(QDomElement* el);
- void restorePartialProjectSession(const QDomElement* el);
+ void savePartialProjectSession(TQDomElement* el);
+ void restorePartialProjectSession(const TQDomElement* el);
void clear();
@@ -49,38 +49,38 @@ public slots:
void slotInternalCommandStdout(const char* line);
void slotUserCommandStdout(const char* line);
void slotReceivedStderr(const char* line);
- void slotDbgStatus (const QString &status, int statusFlag);
+ void slotDbgStatus (const TQString &status, int statusFlag);
void slotGDBCmd();
void flushPending();
protected:
- virtual void focusInEvent(QFocusEvent *e);
+ virtual void focusInEvent(TQFocusEvent *e);
signals:
- void userGDBCmd(const QString &cmd);
+ void userGDBCmd(const TQString &cmd);
void breakInto();
private:
- QString html_escape(const QString& s);
+ TQString html_escape(const TQString& s);
- void newStdoutLine(const QString& line, bool internal);
+ void newStdoutLine(const TQString& line, bool internal);
/** Arranges for 'line' to be shown to the user.
Adds 'line' to pendingOutput_ and makes sure
updateTimer_ is running. */
- void showLine(const QString& line);
+ void showLine(const TQString& line);
/** Makes 'l' no longer then 'max_size' by
removing excessive elements from the top.
*/
- void trimList(QStringList& l, unsigned max_size);
+ void trimList(TQStringList& l, unsigned max_size);
KHistoryCombo* m_userGDBCmdEditor;
- QToolButton* m_Interrupt;
- QTextEdit* m_gdbView;
+ TQToolButton* m_Interrupt;
+ TQTextEdit* m_gdbView;
void setShowInternalCommands(bool);
friend class OutputText;
@@ -90,39 +90,39 @@ private:
"Show internal commands" on, we can show previous
internal commands.
*/
- QStringList userCommands_, allCommands_;
+ TQStringList userCommands_, allCommands_;
/** Same output, without any fancy formatting. Keeping it
here because I can't find any way to extract raw text,
- without formatting, out of QTextEdit except for
+ without formatting, out of TQTextEdit except for
selecting everything and calling 'copy()'. The latter
approach is just ugly. */
- QStringList userCommandsRaw_, allCommandsRaw_;
+ TQStringList userCommandsRaw_, allCommandsRaw_;
/** For performance reasons, we don't immediately add new text
to QTExtEdit. Instead we add it to pendingOutput_ and
flush it on timer.
*/
- QString pendingOutput_;
- QTimer updateTimer_;
+ TQString pendingOutput_;
+ TQTimer updateTimer_;
bool showInternalCommands_;
int maxLines_;
};
/** Add popup menu specific to gdb output window to QTextEdit.
*/
class OutputText : public QTextEdit
{
Q_OBJECT
public:
OutputText(GDBOutputWidget* parent)
- : QTextEdit(parent),
+ : TQTextEdit(parent),
parent_(parent)
{}
- QPopupMenu* createPopupMenu(const QPoint& pos);
+ TQPopupMenu* createPopupMenu(const TQPoint& pos);
private slots:
void copyAll();
@@ -90,39 +90,39 @@ private:
int maxLines_;
};
-/** Add popup menu specific to gdb output window to QTextEdit.
+/** Add popup menu specific to gdb output window to TQTextEdit.
*/
class OutputText : public QTextEdit